ESPQRCodePayload class

QR code payload data

Constructors

ESPQRCodePayload({required String name, String? proofOfPossession, required ESPTransportType transport, required ESPSecurityType security, String? username, String? password})
ESPQRCodePayload.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Device name
final
password String?
Password
final
proofOfPossession String?
Proof of possession
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security ESPSecurityType
Security type
final
transport ESPTransportType
Transport type
final
username String?
Username (for Security 2)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited