MethodChannelEspIdf class

An implementation of EspIdfPlatform that uses method channels.

Inheritance

Constructors

MethodChannelEspIdf()

Properties

bleDeviceEventChannel → EventChannel
Event channel for BLE device discovery
final
connectionEventChannel → EventChannel
Event channel for connection status
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
provisioningEventChannel → EventChannel
Event channel for provisioning status
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPermissions() → Future<bool>
Check if required permissions are granted
override
connectDevice(String deviceId) → Future<void>
Connect to a device
override
connectWiFiDevice(String deviceId) → Future<void>
Connect to device via WiFi (SoftAP) This is used for SoftAP transport mode
override
createDevice({required String deviceName, required ESPTransportType transport, required ESPSecurityType security, String? proofOfPossession, String? username, String? softApPassword, String? primaryServiceUuid}) → Future<String>
Create a device instance manually
override
disconnectDevice(String deviceId) → Future<void>
Disconnect from a device
override
getConnectionStatusStream(String deviceId) → Stream<ESPConnectionStatus>
Get device connection status stream
override
getProvisioningStatusStream(String deviceId) → Stream<ESPProvisionStatus>
Get provisioning status stream
override
isBluetoothEnabled() → Future<bool>
Check if Bluetooth is enabled
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provisionDevice({required String deviceId, required String ssid, String? password}) → Future<void>
Provision the device with Wi-Fi credentials
override
requestPermissions() → Future<bool>
Request required permissions
override
scanQRCode({String? title, String? description, String? cancelButtonText}) → Future<ESPQRCodePayload>
Scan QR code to get device provisioning information
override
scanWifiNetworks(String deviceId) → Future<List<ESPWifiNetwork>>
Scan for available Wi-Fi networks
override
searchBleDevices(String prefix) → Stream<ESPDevice>
Start searching for BLE devices with the given prefix Returns a stream of discovered devices
override
stopBleSearch() → Future<void>
Stop searching for BLE devices
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited