ESPDevice class
Represents an ESP device discovered during scanning
Constructors
-
ESPDevice({required String name, required ESPTransportType transport, required ESPSecurityType security, String? deviceId, String? primaryServiceUuid, String? proofOfPossession, String? username, List<
String> ? capabilities, String? versionInfo}) -
ESPDevice.fromMap(Map<
String, dynamic> map) -
factory
Properties
-
capabilities
→ List<
String> ? -
Device capabilities
final
- deviceId → String?
-
Device identifier (MAC address for BLE, IP for SoftAP)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Device name
final
- primaryServiceUuid → String?
-
Primary service UUID (for BLE devices)
final
- proofOfPossession → String?
-
Proof of possession (optional)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- security → ESPSecurityType
-
Security type
final
- transport → ESPTransportType
-
Transport type (BLE or SoftAP)
final
- username → String?
-
Username (required for Security 2)
final
- versionInfo → String?
-
Version information
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited