ESPWifiNetwork class
Represents a Wi-Fi network
Constructors
- ESPWifiNetwork({required String ssid, required int rssi, required int auth, int? channel})
-
ESPWifiNetwork.fromMap(Map<
String, dynamic> map) -
factory
Properties
- auth → int
-
Authentication mode
final
- authModeString → String
-
Get authentication mode as string
no setter
- channel → int?
-
Channel number
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rssi → int
-
Signal strength (RSSI)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssid → String
-
Network SSID
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited